{% extends "djangocms_frontend/admin/base.html" %}
{% load static %}
{% block extrahead %}
    {{ block.super }}
    <script src="{% static 'djangocms_frontend/js/bundle.utilities.js' %}"></script>
{% endblock %}
{% block custom_class %}djangocms-frontend-tabs{% endblock %}
