@media(prefers-color-scheme: dark){.select2-container--default .select2-selection--single,.select2-dropdown{background:var(--dca-white, #121212)}.select2-container--default .select2-results__option[aria-selected=true]{background:var(--dca-gray, #00363a)}.select2-container--default .select2-selection--single .select2-selection__rendered{color:var(--dca-black, #eee)}.popover{background:var(--dca-white, #121212)}}ul.select2-results__options{color-scheme:dark light}/*# sourceMappingURL=select2.css.map */
